==> OpenPatricianDisplay-0.9.1-sources.jar: ch/sahits/game/openpatrician/display/javafx/DisplayMessageOverlay.java <==
package ch.sahits.game.openpatrician.display.javafx;

import ch.sahits.game.openpatrician.display.event.handler.impl.EventHandlerFactory;
import ch.sahits.game.openpatrician.javafx.control.DisplayMessageOverlayLabel;
import ch.sahits.game.openpatrician.javafx.control.TextSizingUtility;
import ch.sahits.game.openpatrician.model.DisplayMessage;
import ch.sahits.game.openpatrician.model.DisplayStateMessage;
import ch.sahits.game.openpatrician.model.DisplayTemplateMessage;
import ch.sahits.game.openpatrician.model.product.EWare;
import ch.sahits.game.openpatrician.model.service.ModelTranslations;
import ch.sahits.game.openpatrician.utilities.annotation.ClassCategory;
import ch.sahits.game.openpatrician.utilities.annotation.EClassCategory;
import ch.sahits.game.openpatrician.utilities.annotation.LazySingleton;
import ch.sahits.game.openpatrician.utilities.l10n.Locale;
import com.google.common.eventbus.AsyncEventBus;
import com.google.common.eventbus.Subscribe;
import javafx.animation.FadeTransition;
import javafx.application.Platform;
import javafx.event.EventHandler;
import javafx.scene.input.MouseEvent;
import javafx.scene.layout.VBox;
import javafx.util.Duration;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.context.MessageSource;

import javax.annotation.PostConstruct;
import javax.annotation.PreDestroy;
import java.util.TimerTask;
import java.util.concurrent.ScheduledExecutorService;
import java.util.concurrent.TimeUnit;

/**
 * @author Andi Hotz, (c) Sahits GmbH, 2015
 *         Created on Mar 04, 2015
 */
@LazySingleton
@ClassCategory(EClassCategory.HANDLER)
public class DisplayMessageOverlay extends VBox {
    private final Logger logger = LogManager.getLogger(getClass());

    private final static int DISPLAY_MESSAGE_FOR_SECONDS = 15;

    @Autowired
    @Qualifier("clientEventBus")
    private AsyncEventBus clientEventBus;
    @Autowired
    @Qualifier("serverClientEventBus")
    private AsyncEventBus clientServerEventBus;
    @Autowired
    @Qualifier("uiTimer")
    private ScheduledExecutorService uiTimer;
    @Autowired
    private TextSizingUtility sizeing;
    @Autowired
    private EventHandlerFactory eventHandlerFactory;
    @Autowired
    private Locale locale;
    @Autowired
    private MessageSource messageSource;
    @Autowired
    private ModelTranslations translator;
    public DisplayMessageOverlay() {
    }
    @PostConstruct
    private void init() {
        clientEventBus.register(this);
        clientServerEventBus.register(this);
    }
    @PreDestroy
    private void unregister() {
        clientEventBus.unregister(this);
        clientServerEventBus.unregister(this);
    }
    @Subscribe
    public void handleMessage(DisplayMessage message) {
        Object[] args = message.getMessageArguments();
        for (int i = 0; i < args.length; i++) {
            if (args[i] instanceof EWare) {
                args[i] = translator.getLocalDisplayName((EWare) args[i]);
            }
        }
        String translatedMessage = messageSource.getMessage(message.getMessageKey(), args, locale.getCurrentLocal());
        DisplayMessageOverlayLabel label = new DisplayMessageOverlayLabel(translatedMessage, sizeing);
        if (message instanceof DisplayTemplateMessage) {
            label.setLinkText(true);
            EventHandler<MouseEvent> openDialogEvenHandler = createEventHandlerFromRunnable(eventHandlerFactory.getViewChangeActionRunnable(((DisplayTemplateMessage)message).getDialogTemplate()));
            label.setOnMouseReleased(openDialogEvenHandler);
        } else if (message instanceof DisplayStateMessage) {
            label.setLinkText(true);
            EventHandler<MouseEvent> openDialogEvenHandler = createEventHandlerFromRunnable(eventHandlerFactory.getViewChangeActionRunnable(((DisplayStateMessage)message).getState()));
            label.setOnMouseReleased(openDialogEvenHandler);
        }
        TimerTask task = new TimerTask() {
            @Override
            public void run() {
                Platform.runLater(() -> {
                    try {
                        FadeTransition ft = new FadeTransition(Duration.millis(2000), label);
                        ft.setFromValue(1.0);
                        ft.setToValue(0);

                        ft.setAutoReverse(false);
                        ft.setOnFinished(event -> getChildren().remove(label));

                        ft.play();
                    } catch (RuntimeException e) {
                        logger.error("Failed to fade transition", e);
                    }
                });
            }
        };

        uiTimer.schedule(task, DISPLAY_MESSAGE_FOR_SECONDS, TimeUnit.SECONDS);
        Platform.runLater(() -> getChildren().add(0, label));
    }

    /**
     * Helper method to convert the old event triggering into JavaFX events.
     * @param run runnable that is executed on mouse click
     * @return event handler for a mouse event
     */
    private EventHandler<MouseEvent> createEventHandlerFromRunnable(final Runnable run) {
        return arg0 -> {
            try {
                run.run();
            } catch (RuntimeException e) {
                logger.error("Failed to execute runnable", e);
            }
        };

    }
}

==> OpenPatricianDisplay-1.0.1-sources.jar: ch/sahits/game/openpatrician/display/javafx/DisplayMessageOverlay.java <==
package ch.sahits.game.openpatrician.display.javafx;

import ch.sahits.game.openpatrician.display.event.handler.impl.EventHandlerFactory;
import ch.sahits.game.openpatrician.javafx.control.DisplayMessageOverlayLabel;
import ch.sahits.game.openpatrician.javafx.control.TextSizingUtility;
import ch.sahits.game.openpatrician.model.DisplayStateMessage;
import ch.sahits.game.openpatrician.model.DisplayTemplateMessage;
import ch.sahits.game.openpatrician.model.IDisplayableMessage;
import ch.sahits.game.openpatrician.model.product.EWare;
import ch.sahits.game.openpatrician.model.service.ModelTranslations;
import ch.sahits.game.openpatrician.utilities.annotation.ClassCategory;
import ch.sahits.game.openpatrician.utilities.annotation.EClassCategory;
import ch.sahits.game.openpatrician.utilities.annotation.LazySingleton;
import ch.sahits.game.openpatrician.utilities.l10n.Locale;
import com.google.common.eventbus.AsyncEventBus;
import com.google.common.eventbus.Subscribe;
import javafx.animation.FadeTransition;
import javafx.application.Platform;
import javafx.event.EventHandler;
import javafx.scene.input.MouseEvent;
import javafx.scene.layout.VBox;
import javafx.util.Duration;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.context.MessageSource;

import javax.annotation.PostConstruct;
import javax.annotation.PreDestroy;
import java.util.TimerTask;
import java.util.concurrent.ScheduledExecutorService;
import java.util.concurrent.TimeUnit;

/**
 * @author Andi Hotz, (c) Sahits GmbH, 2015
 *         Created on Mar 04, 2015
 */
@Slf4j
@LazySingleton
@ClassCategory(EClassCategory.HANDLER)
public class DisplayMessageOverlay extends VBox {

    private final static int DISPLAY_MESSAGE_FOR_SECONDS = 15;

    @Autowired
    @Qualifier("clientEventBus")
    private AsyncEventBus clientEventBus;
    @Autowired
    @Qualifier("serverClientEventBus")
    private AsyncEventBus clientServerEventBus;
    @Autowired
    @Qualifier("uiTimer")
    private ScheduledExecutorService uiTimer;
    @Autowired
    private TextSizingUtility sizeing;
    @Autowired
    private EventHandlerFactory eventHandlerFactory;
    @Autowired
    private Locale locale;
    @Autowired
    private MessageSource messageSource;
    @Autowired
    private ModelTranslations translator;
    public DisplayMessageOverlay() {
    }
    @PostConstruct
    private void init() {
        clientEventBus.register(this);
        clientServerEventBus.register(this);
    }
    @PreDestroy
    private void unregister() {
        clientEventBus.unregister(this);
        clientServerEventBus.unregister(this);
    }
    @Subscribe
    public void handleMessage(IDisplayableMessage message) {
        Object[] args = message.getMessageArguments();
        for (int i = 0; i < args.length; i++) {
            if (args[i] instanceof EWare) {
                args[i] = translator.getLocalDisplayName((EWare) args[i]);
            }
        }
        String translatedMessage = messageSource.getMessage(message.getMessageKey(), args, locale.getCurrentLocal());
        DisplayMessageOverlayLabel label = new DisplayMessageOverlayLabel(translatedMessage, sizeing);
        if (message instanceof DisplayTemplateMessage) {
            label.setLinkText(true);
            EventHandler<MouseEvent> openDialogEvenHandler = createEventHandlerFromRunnable(eventHandlerFactory.getViewChangeActionRunnable(((DisplayTemplateMessage)message).getDialogTemplate()));
            label.setOnMouseReleased(openDialogEvenHandler);
        } else if (message instanceof DisplayStateMessage) {
            label.setLinkText(true);
            EventHandler<MouseEvent> openDialogEvenHandler = createEventHandlerFromRunnable(eventHandlerFactory.getViewChangeActionRunnable(((DisplayStateMessage)message).getState()));
            label.setOnMouseReleased(openDialogEvenHandler);
        }
        TimerTask task = new TimerTask() {
            @Override
            public void run() {
                Platform.runLater(() -> {
                    try {
                        FadeTransition ft = new FadeTransition(Duration.millis(2000), label);
                        ft.setFromValue(1.0);
                        ft.setToValue(0);

                        ft.setAutoReverse(false);
                        ft.setOnFinished(event -> getChildren().remove(label));

                        ft.play();
                    } catch (RuntimeException e) {
                        log.error("Failed to fade transition", e);
                    }
                });
            }
        };

        uiTimer.schedule(task, DISPLAY_MESSAGE_FOR_SECONDS, TimeUnit.SECONDS);
        Platform.runLater(() -> getChildren().add(0, label));
    }

    /**
     * Helper method to convert the old event triggering into JavaFX events.
     * @param run runnable that is executed on mouse click
     * @return event handler for a mouse event
     */
    private EventHandler<MouseEvent> createEventHandlerFromRunnable(final Runnable run) {
        return arg0 -> {
            try {
                run.run();
            } catch (RuntimeException e) {
                log.error("Failed to execute runnable", e);
            }
        };

    }
}
